@@ -19,15 +19,13 @@ class Bar_Py:
         self.subtitle = subtitle
         self.args = args
 
-    def one_bar_air(self):
-        c = (
-            Bar()
-                .add_xaxis(self.x_value)
-                .add_yaxis(self.y_name, self.y_value)
-                .add_yaxis(self.args[0], self.args[1])
-                .set_global_opts(
-                    xaxis_opts=opts.AxisOpts(axislabel_opts=opts.LabelOpts(rotate=-15)),
-                    title_opts=opts.TitleOpts(title=self.title, subtitle=self.subtitle),
-            )
+    def bar_render_air(self):
+        c = Bar()
+        c.add_xaxis(self.x_value)
+        c.add_yaxis(self.y_name, self.y_value)
+        c.set_global_opts(
+            title_opts=opts.TitleOpts(title=self.title, subtitle=self.subtitle),
         )
+        for agr_data in self.args:
+            c.add_yaxis(agr_data[0], agr_data[1])
         return c
\ No newline at end of file
